Changelog

### 1.0.0 (2017-04-07)

  * Initial public release

### 1.0.1 (2017-04-13)

  * Integration with pypi and ReadTheDocs.
  * Installation on Mac and Windows.

### 1.0.2 (2017-04-26)

  * Metadata and badge for Python version.
  * Python 3 compatibility changes, part 1.
  * Installation with Coveralls.

### 1.0.3 (2017-04-26)

  * Bugfix: Import of urlparse corrected, fixes Block.show() .

### 1.1.0 (2017-05-10)

  * jQuery DataTables support.
  * HTML anchors.
  * Bugfix: Width of HTML-body no longer hard-coded.

### 1.1.1 (2017-05-10)

  * Bugfix: Static data including DataTables CSS.
  